@@ -16,6 +16,14 @@ def load_class(path):
 
 
 def generic_autodiscover(module_name):
+    """
+    I have copy/pasted this code too many times...Dynamically autodiscover a
+    particular module_name in a django project's INSTALLED_APPS directories,
+    a-la django admin's autodiscover() method.
+    
+    Usage:
+        generic_autodiscover('commands') <-- find all commands.py and load 'em
+    """
     import imp
     from django.conf import settings
 
